amd_ordering

Function amd_ordering 

pub fn amd_ordering<T: GpuFloat>(
    matrix: &CsrMatrix<T>,
) -> SparseResult<Vec<usize>>
Compute the Approximate Minimum Degree (AMD) ordering of a sparse matrix.

AMD is a greedy fill-reducing ordering for Cholesky and LU factorization. At each step, the node with minimum approximate degree is eliminated.

Arguments

  • matrix – A square CSR matrix.

Returns

A permutation vector perm of length n where perm[i] is the i-th node to be eliminated.

Errors

Returns SparseError::DimensionMismatch if the matrix is not square.