Crate oxicuda_sparse

Crate oxicuda_sparse 

OxiCUDA Sparse – GPU-Accelerated Sparse Matrix Operations

This crate provides GPU-accelerated sparse matrix operations, serving as a pure Rust equivalent to NVIDIA’s cuSPARSE library.

Sparse formats

Multiple storage formats are supported via the format module:

Operations

  • ops::spmv – Sparse matrix-vector multiply (y = alpha*A*x + beta*y)
  • ops::spmm – Sparse-dense matrix multiply (C = alpha*A*B + beta*C)
  • ops::spgemm – Sparse-sparse matrix multiply (C = A*B)
  • ops::sptrsv – Sparse triangular solve (L*x = b or U*x = b)
  • ops::sddmm – Sampled Dense-Dense Matrix Multiply

Preconditioners

Example

use oxicuda_sparse::prelude::*;

Re-exports

pub use error::SparseError;
pub use error::SparseResult;
pub use format::BsrMatrix;
pub use format::CooMatrix;
pub use format::CscMatrix;
pub use format::Csr5Matrix;
pub use format::CsrMatrix;
pub use format::EllMatrix;
pub use format::HybMatrix;
pub use format::HybPartition;
pub use format::HybStatistics;
pub use handle::SparseHandle;

Modules

error
Error types for OxiCUDA Sparse operations.
format
Sparse matrix storage formats.
handle
Sparse handle management.
ops
Sparse matrix operations.
preconditioner
Incomplete factorization preconditioners for iterative solvers.
prelude
Prelude for convenient imports.