Coordinate (COO) format.
COO stores each non-zero as a (row, col, value) triplet. It is the
simplest sparse format and is commonly used as an intermediate format
for assembly before converting to CSR or CSC.
The triplets can be in any order, but sorted COO enables more efficient conversion to CSR.
Structs
- CooMatrix
- A sparse matrix in Coordinate (COO) format, stored on GPU.