TileDescriptor

Struct TileDescriptor 

#[repr(C)]
pub struct TileDescriptor { pub seg_mask: u32, pub first_row: u32, }
Tile descriptor: bit-packed row boundary information for one tile.

The descriptor encodes:

  • y_offset: the starting row offset (local within the tile’s first row)
  • seg_offset: bitmask indicating which lanes in the warp start a new row
  • empty_offset: number of empty (padding) elements at the end of the tile

This allows each warp to determine which rows its non-zero elements belong to and how to reduce partial sums correctly.

Fields

seg_mask: u32

Bitmask: bit i is set if lane i starts a new row segment.

first_row: u32

Index of the first row that this tile contributes to.